@@ -159,7 +159,7 @@ quote_summary_valid_modules = (
     "futuresChain",
 )
 
-# map last updated as of 2024.09.18
+# map last updated as of 2025.12.19
 SECTOR_INDUSTY_MAPPING = {
     'Basic Materials': {'Specialty Chemicals',
                         'Gold',
@@ -205,9 +205,9 @@ SECTOR_INDUSTY_MAPPING = {
                             'Specialty Retail',
                             'Textile Manufacturing',
                             'Travel Services'},
-    'Consumer Defensive': {'Beverages - Brewers',
-                            'Beverages - Non-Alcoholic',
-                            'Beverages - Wineries & Distilleries',
+    'Consumer Defensive': {'Beverages—Brewers',
+                            'Beverages—Non-Alcoholic',
+                            'Beverages—Wineries & Distilleries',
                             'Confectioners',
                             'Discount Stores',
                             'Education & Training Services',
@@ -217,95 +217,95 @@ SECTOR_INDUSTY_MAPPING = {
                             'Household & Personal Products',
                             'Packaged Foods',
                             'Tobacco'},
-    'Energy': {'Oil Gas Drilling',
-                'Oil Gas E P',
-                'Oil Gas Equipment Services',
-                'Oil Gas Integrated',
-                'Oil Gas Midstream',
-                'Oil Gas Refining Marketing',
+    'Energy': {'Oil & Gas Drilling',
+                'Oil & Gas E&P',
+                'Oil & Gas Equipment & Services',
+                'Oil & Gas Integrated',
+                'Oil & Gas Midstream',
+                'Oil & Gas Refining & Marketing',
                 'Thermal Coal',
                 'Uranium'},
     'Financial Services': {'Asset Management',
-                            'Banks Diversified',
-                            'Banks Regional',
+                            'Banks—Diversified',
+                            'Banks—Regional',
                             'Capital Markets',
                             'Credit Services',
                             'Financial Conglomerates',
-                            'Financial Data Stock Exchanges',
+                            'Financial Data & Stock Exchanges',
                             'Insurance Brokers',
-                            'Insurance Diversified',
-                            'Insurance Life',
-                            'Insurance Property Casualty',
-                            'Insurance Reinsurance',
-                            'Insurance Specialty',
+                            'Insurance—Diversified',
+                            'Insurance—Life',
+                            'Insurance—Property & Casualty',
+                            'Insurance—Reinsurance',
+                            'Insurance—Specialty',
                             'Mortgage Finance',
                             'Shell Companies'},
     'Healthcare': {'Biotechnology',
-                    'Diagnostics Research',
-                    'Drug Manufacturers General',
-                    'Drug Manufacturers Specialty Generic',
+                    'Diagnostics & Research',
+                    'Drug Manufacturers—General',
+                    'Drug Manufacturers—Specialty & Generic',
                     'Health Information Services',
                     'Healthcare Plans',
                     'Medical Care Facilities',
                     'Medical Devices',
+                    'Medical Instruments & Supplies',
                     'Medical Distribution',
-                    'Medical Instruments Supplies',
                     'Pharmaceutical Retailers'},
-    'Industrials': {'Aerospace Defense',
+    'Industrials': {'Aerospace & Defense',
                     'Airlines',
-                    'Airports Air Services',
-                    'Building Products Equipment',
-                    'Business Equipment Supplies',
+                    'Airports & Air Services',
+                    'Building Products & Equipment',
+                    'Business Equipment & Supplies',
                     'Conglomerates',
                     'Consulting Services',
-                    'Electrical Equipment Parts',
-                    'Engineering Construction',
-                    'Farm Heavy Construction Machinery',
+                    'Electrical Equipment & Parts',
+                    'Engineering & Construction',
+                    'Farm & Heavy Construction Machinery',
                     'Industrial Distribution',
                     'Infrastructure Operations',
-                    'Integrated Freight Logistics',
+                    'Integrated Freight & Logistics',
                     'Marine Shipping',
                     'Metal Fabrication',
-                    'Pollution Treatment Controls',
+                    'Pollution & Treatment Controls',
                     'Railroads',
-                    'Rental Leasing Services',
-                    'Security Protection Services',
+                    'Rental & Leasing Services',
+                    'Security & Protection Services',
                     'Specialty Business Services',
                     'Specialty Industrial Machinery',
-                    'Staffing Employment Services',
-                    'Tools Accessories',
+                    'Staffing & Employment Services',
+                    'Tools & Accessories',
                     'Trucking',
                     'Waste Management'},
-    'Real Estate': {'Real Estate Development',
-                    'Real Estate Diversified',
+    'Real Estate': {'Real Estate—Development',
                     'Real Estate Services',
-                    'Reit Diversified',
-                    'Reit Healthcare Facilities',
-                    'Reit Hotel Motel',
-                    'Reit Industrial',
-                    'Reit Mortgage',
-                    'Reit Office',
-                    'Reit Residential',
-                    'Reit Retail',
-                    'Reit Specialty'},
+                    'Real Estate—Diversified',
+                    'REIT—Healthcare Facilities',
+                    'REIT—Hotel & Motel',
+                    'REIT—Industrial',
+                    'REIT—Office',
+                    'REIT—Residential',
+                    'REIT—Retail',
+                    'REIT—Mortgage',
+                    'REIT—Specialty',
+                    'REIT—Diversified'},
     'Technology': {'Communication Equipment',
                     'Computer Hardware',
                     'Consumer Electronics',
                     'Electronic Components',
-                    'Electronics Computer Distribution',
+                    'Electronics & Computer Distribution',
                     'Information Technology Services',
-                    'Scientific Technical Instruments',
-                    'Semiconductor Equipment Materials',
+                    'Scientific & Technical Instruments',
+                    'Semiconductor Equipment & Materials',
                     'Semiconductors',
-                    'Software Application',
-                    'Software Infrastructure',
+                    'Software—Application',
+                    'Software—Infrastructure',
                     'Solar'},
-    'Utilities': {'Utilities Diversified',
-                    'Utilities Independent Power Producers',
-                    'Utilities Regulated Electric',
-                    'Utilities Regulated Gas',
-                    'Utilities Regulated Water',
-                    'Utilities Renewable'},
+    'Utilities': {'Utilities—Diversified',
+                    'Utilities—Independent Power Producers',
+                    'Utilities—Regulated Electric',
+                    'Utilities—Regulated Gas',
+                    'Utilities—Regulated Water',
+                    'Utilities—Renewable'},
 }
 SECTOR_INDUSTY_MAPPING_LC = {}
 for k in SECTOR_INDUSTY_MAPPING.keys():
